"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.ParseText = exports.ParseFile = void 0;
const fs = require("fs");
const types_1 = require("./types");
/** Parses the utf-8 content of a given file's content.
 * @param path The path to the file to parse.
 * @param parser The parser to use.
 * @returns The result of the parse.
 * @throws {ParseError} if the parsing fails or the parser does not consume the full input.
 */
function ParseFile(path, parser) {
    const text = fs.readFileSync(path, 'utf8');
    return ParseText(text, parser, path);
}
exports.ParseFile = ParseFile;
/** Parses the given string.
 * @param text The string to parse.
 * @param parser The parser to use.
 * @param path The path of the parsed text. Can be used for error reporting.
 * @returns The result of the parse.
 * @throws {ParseError} if the parsing fails or the parser does not consume the full input.
 */
function ParseText(text, parser, path = '') {
    const res = parser({ text, path, index: 0 });
    if (types_1.isFailure(res)) {
        throw new types_1.ParseError(`Parse error, expected ${[...res.history].pop()} at char ${res.ctx.index}`, text, res.ctx.index, res.history);
    }
    if (res.ctx.index !== text.length) {
        throw new types_1.ParseError(`Parse error at index ${res.ctx.index}`, text, res.ctx.index, []);
    }
    return res.value;
}
exports.ParseText = ParseText;
