"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.map = void 0;
const types_1 = require("../types");
/** Parses the input using the given parser, then maps the output.
 * @returns A parser that parses the same input, but has output mapped using the mapping function.
 */
function map(parser, mapper) {
    return (ctx) => {
        const res = parser(ctx);
        if (types_1.isFailure(res))
            return types_1.failure(res.ctx, res.expected, ['map', ...res.history]);
        try {
            const newValue = mapper(res.value);
            return types_1.success(res.ctx, newValue);
        }
        catch (e) {
            console.trace('Error while mapping: ', e);
            return types_1.failure(res.ctx, 'Error while mapping', ['map']);
        }
    };
}
exports.map = map;
